==> wurld-0.3.tar.gz: wurld-0.3/src/PythonPluginInternal.h <==
#ifndef PYTHONPLUGININTERNAL_H
#define PYTHONPLUGININTERNAL_H

#include <spug/RCPtr.h>
#include "Vector.h"

typedef struct _object PyObject;

SPUG_RCPTR(KeyCommand);
KeyCommandPtr createKeyCommand(PyObject *onKeyPress, PyObject *onKeyRelease);

class DisplayDriver;
DisplayDriver *getDisplayDriver();

class GameEngine;
GameEngine *getGameEngine();

class RotMatrix;
RotMatrix createYawRotMatrix(Float degrees);
RotMatrix createPitchRotMatrix(Float degrees);
RotMatrix createRollRotMatrix(Float degrees);

Vector createVector(Float x, Float y, Float z);

SPUG_RCPTR(Texture);
TexturePtr createTexture(const char *filename);

SPUG_RCPTR(Material);
MaterialPtr createTextureMaterial(const TexturePtr &texture, 
				  Float xppus, 
				  Float yppus
				  );

class AxisBox;

SPUG_RCPTR(PolyObj);
PolyObjPtr createQuad(Vector c0, Vector c1, Vector c2, Vector c3, 
		      const MaterialPtr &material
		      );

SPUG_RCPTR(Model);
ModelPtr createModel();

SPUG_RCPTR(SimpleCollidable);
SimpleCollidablePtr createSimpleCollidable(const AxisBox &box);

SPUG_RCPTR(CollisionAlgo);
CollisionAlgoPtr createPointCollisionAlgo();

SPUG_RCPTR(Moveable);
MoveablePtr createMoveable();

SPUG_RCPTR(RenderableObject);
RenderableObjectPtr createSimpleText(const char *text, Float left, Float top,
                                     Float width,
                                     Float height
                                     );

RenderableObjectPtr createFPSDisplay(GameEngine *engine);

class PythonObject;
PythonObject *createPythonObject();

class Graphics;
Graphics *getGraphics();

char *getVersion();

#endif

==> wurld-0.4.tar.gz: wurld-0.4/src/PythonPluginInternal.h <==
#ifndef PYTHONPLUGININTERNAL_H
#define PYTHONPLUGININTERNAL_H

#include <spug/RCPtr.h>
#include "Vector.h"
#include "Color.h"

typedef struct _object PyObject;

SPUG_RCPTR(KeyCommand);
KeyCommandPtr createKeyCommand(PyObject *onKeyPress, PyObject *onKeyRelease);

class DisplayDriver;
DisplayDriver *getDisplayDriver();

class GameEngine;
GameEngine *getGameEngine();

class AudioDriver;
AudioDriver *getAudioDriver();

class RotMatrix;
RotMatrix createYawRotMatrix(Float degrees);
RotMatrix createPitchRotMatrix(Float degrees);
RotMatrix createRollRotMatrix(Float degrees);

Vector createVector(Float x, Float y, Float z);

Color createColor(Float red, Float green, Float blue);

SPUG_RCPTR(Material);
MaterialPtr createColorMaterial(const Color &color);

SPUG_RCPTR(Texture);
TexturePtr createTexture(const char *filename);

MaterialPtr createTextureMaterial(const TexturePtr &texture, 
				  Float xppus, 
				  Float yppus
				  );

class AxisBox;

SPUG_RCPTR(PolyObj);
PolyObjPtr createQuad(Vector c0, Vector c1, Vector c2, Vector c3, 
		      const MaterialPtr &material
		      );

SPUG_RCPTR(SphereObj);
SphereObjPtr createSphereObj(const Vector &center, Float radius,
                             const MaterialPtr &material
                             );

SPUG_RCPTR(Model);
ModelPtr createModel();

SPUG_RCPTR(SimpleCollidable);
SimpleCollidablePtr createSimpleCollidable(const AxisBox &box);

SPUG_RCPTR(CollisionAlgo);
CollisionAlgoPtr createPointCollisionAlgo();

SPUG_RCPTR(Moveable);
MoveablePtr createMoveable();

SPUG_RCPTR(TextPane);
TextPanePtr createSimpleText(const char *text, Float left, Float top,
                             Float width,
                             Float height
                             );

SPUG_RCPTR(QuadPane);
QuadPanePtr createQuadPane(Float left, Float top, Float width, Float height,
                           const MaterialPtr &material
                           );

SPUG_RCPTR(RenderableObject);
RenderableObjectPtr createFPSDisplay(GameEngine *engine);

class PythonObject;
PythonObject *createPythonObject();

class Graphics;
Graphics *getGraphics();

SPUG_RCPTR(Sample);
SamplePtr createWaveFile(const char *filename);

char *getVersion();

#endif
